@@ -1,11 +1,14 @@
-#!/bin/bash
+#!/bin/sh
 
 ## Testing aware output
 echo "TEST: params=$*"
 echo "TEST: executed=false"
 
 ## execute the command
-[[ ! -z $1 ]] && echo "TEST: executed=true" && $*
+if [ "$1" != "" ]; then
+    echo "TEST: executed=true"
+    $*
+fi
 
 ## Testing aware output
 echo "TEST: output=$?"
